local objects = {}

fileManager = {}
fileManager.__index = fileManager

fileManager.getDir = function( s )
	if love.filesystem.isDirectory( s ) and not objects[s] then
		objects[s] = true
		local self = {
			directory = s;
			getFiles = function( self )
				return (function()
					local list = {}
					for _, v in pairs( love.filesystem.enumerate(self.directory) ) do
						table.insert( list, v )
					end
					return list
				end)()
			end;
			getLongestStr = function( self )
				local list = self:getFiles()
				local longest = ""
				for _, v in pairs( list ) do
					if longest:len() < v:len() then
						longest = v
					end
				end
				return longest
			end;
		}
		return setmetatable( self, fileManager )
	else
		error( "Path is not a valid directory.", 2 )
	end
end

local commonAudioExtensions = {
	[".ogg"] = true; [".ra"] = true;
	[".aif"] = true; [".iff"] = true; [".m3u"] = true;
	[".m4a"] = true; [".mid"] = true; [".mp3"] = true;
	[".mpa"] = true; [".wma"] = true; [".wav"] = true;
}

fileManager.isAudio = function( s )
	if commonAudioExtensions[ extManager.getExt( s ) ] then
		return true
	end
	return false
end

fileManager.getName = function( s )
	local components = {}
	for name in string.gmatch( s, "[^/]+" ) do
		table.insert( components, name )
	end
	return extManager.remove( components[#components] )
end

fileManager.exists = function( s )
	return love.filesystem.exists( s )
end

local CONFIG = nil
fileManager.createConfiguration = function()
	local path = love.filesystem.getAppdataDirectory()
	if not love.filesystem.exists( path ) then
		love.filesystem.mkdir( path )
	end
	if not love.filesystem.exists( path .. "paths" ) then
		love.filesystem.setIdentity( path, "first" )
		
		--[[
		This wont write to a file
		CONFIG = love.filesystem.newFile( path .. "paths.txt" )
		CONFIG:open( "w" )
		CONFIG:write( "-- This file is auto created by Music Player." )
		CONFIG:close()
		]]
	end
end

-- I need a function that writes to the config in append mode, but I cant even open a file properly :/
fileManager.writeToConfig = function( s )
	CONFIG:open("w")
	CONFIG:write( s )
	CONFIG:close()
end
	
	
fileManager.getConfiguration = function()

end