local objects = {}
local songs = love.filesystem.enumerate( "/music/" )

musicManager = {}
musicManager.__index = musicManager
musicManager.create = function( s )
	if not objects[s] and fileManager.isAudio( s ) then
		initTime = os.time()
		objects[s] = {}
		objects[s].source = love.audio.newSource( s )
		
		local SoundDataObject = love.sound.newSoundData(love.sound.newDecoder( s, 1024 * 1024 * 5 ))
		objects[s].length = SoundDataObject:getSize() / SoundDataObject:getSampleRate() / SoundDataObject:getChannels() / (SoundDataObject:getBits() / 8)
		
		local self = {
			object = objects[s];
			play = function( self )
				return self.object.source:play()
			end;
			pause = function( self )
				return self.object.source:pause()
			end;
			resume = function( self )
				return self.object.source:resume()
			end;
			stopped = function( self )
				return self.object.source:isStopped()
			end;
			paused = function( self )
				return self.object.source:isPaused()
			end;
			getTitle = function( self )
				return s
			end;
			loop = function( self )
				return self.object.source:setLooping( not self.object.source:isLooping() )
			end;
			getLength = function( self )
				return self.object.length
			end;
			sVolume = function( self, v )
				return self.object.source:setVolume( v )
			end;
			gVolume = function( self )
				return self.object.source:getVolume()
			end
		}
		objects[s].object = setmetatable( self, musicManager )
		print( os.time() - initTime )
	end
	return objects[s].object
end

musicManager.getRandomObj = function( sDir )
	if sDir ~= string.match( sDir, "^/+.+/") then
		error( "'/' expected in path", 2 )
	elseif not love.filesystem.isDirectory( sDir ) then
		error( "Folder expected", 2 )
	end

	local self = {
		folderContent = fileManager.getDir( sDir ):getFiles();
		gottenSongs = {};
		getSeqRandom = function( self )
			local randomSong = math.random( 1, #self.folderContent )
			if #self.gottenSongs == #self.folderContent then
				self.gottenSongs = {}
			end
			while self.gottenSongs[ randomSong ] do
				randomSong = math.random( 1, #self.foldeContentt )
			end

			return musicManager.create( sDir .. self.folderContent[ randomSong ] )
		end;
		getRandom = function( self )
			return musicManager.create( sDir .. self.folderContent[ math.random( 1, #self.folderContent ) ] )
		end
	}
	return setmetatable( self, musicManager )
end

musicManager.update = function( randomSongObj, musicObject )
	if musicObject:stopped() and not musicObject:paused() then
		return randomSongObj:getSeqRandom()
	elseif musicObject:paused() then
		return musicObject
	end
end